@@ -1,7 +1,5 @@
-/* $Xorg: Event.c,v 1.5 2001/02/09 02:03:54 xorgcvs Exp $ */
-
 /***********************************************************
-Copyright 1993 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 1993, Oracle and/or its affiliates. All rights reserved.
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -69,7 +67,6 @@ used in advertising or otherwise to promote the sale, use or other dealings
 in this Software without prior written authorization from The Open Group.
 
 */
-/* $XFree86: xc/lib/Xt/Event.c,v 3.10 2001/12/14 19:56:11 dawes Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -1552,15 +1549,9 @@ void XtMainLoop(void)
 void XtAppMainLoop(
 	XtAppContext app)
 {
-    XEvent event;
-
     LOCK_APP(app);
     do {
-    	XtAppNextEvent(app, &event);
-#ifdef XTHREADS
-	/* assert(app == XtDisplayToApplicationContext(event.xany.display)); */
-#endif
-	XtDispatchEvent(&event);
+	XtAppProcessEvent(app, XtIMAll);
     } while(app->exit_flag == FALSE);
     UNLOCK_APP(app);
 }
