@@ -1,7 +1,5 @@
-/* $Xorg: Intrinsic.c,v 1.4 2001/02/09 02:03:55 xorgcvs Exp $ */
-
 /***********************************************************
-Copyright 1993 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 1993, Oracle and/or its affiliates. All rights reserved.
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -43,7 +41,6 @@ ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
 ******************************************************************/
-/* $XFree86: xc/lib/Xt/Intrinsic.c,v 3.22 2003/01/12 03:55:46 tsi Exp $ */
 
 /*
 
@@ -1324,7 +1321,7 @@ static void FillInLangSubs(
  * The exact value should be documented in the implementation
  * notes for any Xt implementation.
  */
-static char *implementation_default_path(void)
+static const char *implementation_default_path(void)
 {
 #if defined(WIN32)
     static char xfilesearchpath[] = "";
@@ -1371,8 +1368,8 @@ String XtResolvePathname(
     XtFilePredicate predicate)
 {
     XtPerDisplay pd;
-    static char *defaultPath = NULL;
-    char *impl_default = implementation_default_path();
+    static const char *defaultPath = NULL;
+    const char *impl_default = implementation_default_path();
     int idef_len = strlen(impl_default);
     char *massagedPath;
     int bytesAllocd, bytesLeft;
