@@ -1,7 +1,5 @@
-/* $Xorg: TMparse.c,v 1.6 2001/02/09 02:03:58 xorgcvs Exp $ */
-
 /***********************************************************
-Copyright 1993 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 1993, Oracle and/or its affiliates. All rights reserved.
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -43,7 +41,6 @@ ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
 ******************************************************************/
-/* $XFree86: xc/lib/Xt/TMparse.c,v 3.10tsi Exp $ */
 
 /*
 
@@ -116,14 +113,14 @@ typedef TMShortCard	Value;
 typedef void (*ModifierProc)(Value, LateBindingsPtr*, Boolean, Value*);
 
 typedef struct _ModifierRec {
-    char*      name;
+    const char *name;
     XrmQuark   signature;
     ModifierProc modifierParseProc;
     Value      value;
 } ModifierRec, *ModifierKeys;
 
 typedef struct _EventKey {
-    char    	*event;
+    const char  *event;
     XrmQuark	signature;
     EventType	eventType;
     ParseProc	parseDetail;
@@ -131,7 +128,7 @@ typedef struct _EventKey {
 }EventKey, *EventKeys;
 
 typedef struct {
-    char	*name;
+    const char	*name;
     XrmQuark	signature;
     Value	value;
 } NameValueRec, *NameValueTable;
